emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] emacs-24 5981b4b: More doc fixes for bug#19502 -- make doc


From: Eli Zaretskii
Subject: [Emacs-diffs] emacs-24 5981b4b: More doc fixes for bug#19502 -- make documentation less X-specific.
Date: Sun, 04 Jan 2015 18:34:05 +0000

branch: emacs-24
commit 5981b4b1c08d308563ecfd4e3ee9f133d47af3b2
Author: Eli Zaretskii <address@hidden>
Commit: Eli Zaretskii <address@hidden>

    More doc fixes for bug#19502 -- make documentation less X-specific.
    
     doc/lispref/frames.texi (Display Feature Testing): Make the description of
     x-server-version and x-server-vendor less X-specific.
    
     Make doc strings on X and w32 identical.
     src/w32fns.c (Fx_server_version, Fx_server_vendor): Doc fix.
     src/xfns.c (Fx_server_version, Fx_server_vendor): Doc fix.
---
 doc/lispref/ChangeLog   |    5 +++++
 doc/lispref/frames.texi |   24 +++++++++++++++---------
 src/ChangeLog           |    4 ++++
 src/w32fns.c            |   35 ++++++++++++++++++++++++-----------
 src/xfns.c              |   21 ++++++++++++++++-----
 5 files changed, 64 insertions(+), 25 deletions(-)

diff --git a/doc/lispref/ChangeLog b/doc/lispref/ChangeLog
index c4b80a0..c898af5 100644
--- a/doc/lispref/ChangeLog
+++ b/doc/lispref/ChangeLog
@@ -1,3 +1,8 @@
+2015-01-04  Eli Zaretskii  <address@hidden>
+
+       * frames.texi (Display Feature Testing): Make the description of
+       x-server-version and x-server-vendor less X-specific.  (Bug#19502)
+
 2014-12-24  Glenn Morris  <address@hidden>
 
        * control.texi (Pattern matching case statement):
diff --git a/doc/lispref/frames.texi b/doc/lispref/frames.texi
index 2d59227..3c27ab1 100644
--- a/doc/lispref/frames.texi
+++ b/doc/lispref/frames.texi
@@ -2645,20 +2645,26 @@ colors).
 This function returns the number of color cells the screen supports.
 @end defun
 
-  These functions obtain additional information specifically
-about X displays.
+  These functions obtain additional information about the window
+system in use where Emacs shows the specified @var{display}.  (Their
+names begin with @code{x-} for historical reasons.)
 
 @defun x-server-version &optional display
-This function returns the list of version numbers of the X server
-running the display.  The value is a list of three integers: the major
-and minor version numbers of the X protocol, and the
-distributor-specific release number of the X server software itself.
+This function returns the list of version numbers of the GUI window
+system running on @var{display}, such as the X server on GNU and Unix
+systems.  The value is a list of three integers: the major and minor
+version numbers of the protocol, and the distributor-specific release
+number of the window system software itself.  On GNU and Unix systems,
+these are normally the version of the X protocol and the
+distributor-specific release number of the X server software.  On
+MS-Windows, this is the version of the Windows OS.
 @end defun
 
 @defun x-server-vendor &optional display
-This function returns the ``vendor'' that provided the X server
-software (as a string).  Really this means whoever distributes the X
-server.
+This function returns the ``vendor'' that provided the window system
+software (as a string).  On GNU and Unix systems this really means
+whoever distributes the X server.  On MS-Windows this is the vendor ID
+string of the Windows OS (Microsoft).
 
 When the developers of X labeled software distributors as
 ``vendors'', they showed their false assumption that no system could
diff --git a/src/ChangeLog b/src/ChangeLog
index 39acf77..d9dd53b 100644
--- a/src/ChangeLog
+++ b/src/ChangeLog
@@ -1,5 +1,9 @@
 2015-01-04  Eli Zaretskii  <address@hidden>
 
+       * w32fns.c (Fx_server_version, Fx_server_vendor): Doc fix.
+
+       * xfns.c (Fx_server_version, Fx_server_vendor): Doc fix.
+
        * emacs.c (syms_of_emacs) <system-configuration>: Doc fix.
        (Bug#19502)
 
diff --git a/src/w32fns.c b/src/w32fns.c
index 64e0e6d..412e91e 100644
--- a/src/w32fns.c
+++ b/src/w32fns.c
@@ -4842,25 +4842,38 @@ If omitted or nil, that stands for the selected frame's 
display.  */)
 }
 
 DEFUN ("x-server-vendor", Fx_server_vendor, Sx_server_vendor, 0, 1, 0,
-       doc: /* Return the "vendor ID" string of the W32 system (Microsoft).
-The optional argument DISPLAY specifies which display to ask about.
-DISPLAY should be either a frame or a display name (a string).
+       doc: /* Return the "vendor ID" string of the GUI software on TERMINAL.
+
+\(Labeling every distributor as a "vendor" embodies the false assumption
+that operating systems cannot be developed and distributed noncommercially.)
+
+For GNU and Unix systems, this queries the X server software; for
+MS-Windows, this queries the OS.
+
+The optional argument TERMINAL specifies which display to ask about.
+TERMINAL should be a terminal object, a frame or a display name (a string).
 If omitted or nil, that stands for the selected frame's display.  */)
-  (Lisp_Object display)
+  (Lisp_Object terminal)
 {
   return build_string ("Microsoft Corp.");
 }
 
 DEFUN ("x-server-version", Fx_server_version, Sx_server_version, 0, 1, 0,
-       doc: /* Return the version numbers of the server of DISPLAY.
-The value is a list of three integers: the major and minor
-version numbers of the X Protocol in use, and the distributor-specific
-release number.  See also the function `x-server-vendor'.
+       doc: /* Return the version numbers of the GUI software on TERMINAL.
+The value is a list of three integers specifying the version of the GUI
+software in use.
 
-The optional argument DISPLAY specifies which display to ask about.
-DISPLAY should be either a frame or a display name (a string).
+For GNU and Unix system, the first 2 numbers are the version of the X
+Protocol used on TERMINAL and the 3rd number is the distributor-specific
+release number.  For MS-Windows, the 3 numbers report the version and
+the build number of the OS.
+
+See also the function `x-server-vendor'.
+
+The optional argument TERMINAL specifies which display to ask about.
+TERMINAL should be a terminal object, a frame or a display name (a string).
 If omitted or nil, that stands for the selected frame's display.  */)
-  (Lisp_Object display)
+  (Lisp_Object terminal)
 {
   return list3i (w32_major_version, w32_minor_version, w32_build_number);
 }
diff --git a/src/xfns.c b/src/xfns.c
index a9192c8..b21228a 100644
--- a/src/xfns.c
+++ b/src/xfns.c
@@ -3535,10 +3535,15 @@ If omitted or nil, that stands for the selected frame's 
display.  */)
 }
 
 DEFUN ("x-server-vendor", Fx_server_vendor, Sx_server_vendor, 0, 1, 0,
-       doc: /* Return the "vendor ID" string of the X server of display 
TERMINAL.
+       doc: /* Return the "vendor ID" string of the GUI software on TERMINAL.
+
 \(Labeling every distributor as a "vendor" embodies the false assumption
 that operating systems cannot be developed and distributed noncommercially.)
 The optional argument TERMINAL specifies which display to ask about.
+
+For GNU and Unix systems, this queries the X server software; for
+MS-Windows, this queries the OS.
+
 TERMINAL should be a terminal object, a frame or a display name (a string).
 If omitted or nil, that stands for the selected frame's display.  */)
   (Lisp_Object terminal)
@@ -3551,10 +3556,16 @@ If omitted or nil, that stands for the selected frame's 
display.  */)
 }
 
 DEFUN ("x-server-version", Fx_server_version, Sx_server_version, 0, 1, 0,
-       doc: /* Return the version numbers of the X server of display TERMINAL.
-The value is a list of three integers: the major and minor
-version numbers of the X Protocol in use, and the distributor-specific release
-number.  See also the function `x-server-vendor'.
+       doc: /* Return the version numbers of the GUI software on TERMINAL.
+The value is a list of three integers specifying the version of the GUI
+software in use.
+
+For GNU and Unix system, the first 2 numbers are the version of the X
+Protocol used on TERMINAL and the 3rd number is the distributor-specific
+release number.  For MS-Windows, the 3 numbers report the version and
+the build number of the OS.
+
+See also the function `x-server-vendor'.
 
 The optional argument TERMINAL specifies which display to ask about.
 TERMINAL should be a terminal object, a frame or a display name (a string).



reply via email to

[Prev in Thread] Current Thread [Next in Thread]